##  Overview
With the Portal feature, we support EAs in making their data available to a broad audience outside the IT organization. For example, create an Application Portal that is accessible to everyone to order software, issue support tickets, or find application knowledge.
Whereas employees are now empowered to get the software they need and educate themselves with expert knowledge, EAs simultaneously govern permission rights and control that only approved software is being ordered.
With Portals, IT infrastructure data becomes accessible and actionable throughout companies to reduce the number of support requests and increase productivity. Key visuals, such as reports and diagrams, show context for applications directly on portal pages.
